@@ -31,7 +31,7 @@ class Client:
     
 
     def get_proxy_authorization(self, plain_text=0, sign_type="simple"):
-        """获取指定订单访问代理IP的鉴权信息。
+        """获取指定订单访问代理ip的鉴权信息。
         鉴权信息包含用户名密码，用于请求私密代理/独享代理/隧道代理时进行身份验证。
             :return 返回信息的字典
         """
@@ -60,11 +60,9 @@ class Client:
                   如果为字符串则ip之间用逗号隔开
            :return 成功则返回True, 否则抛出异常
         """
-
-        if iplist is None:
-            raise KdlNameError("miss param: iplist")
-        if not (isinstance(iplist, list) or isinstance(iplist, tuple) or isinstance(iplist, str)):
-            raise KdlTypeError("iplist type error, should be a instance of list or tuple or str")
+        if  iplist:
+            if not (isinstance(iplist, list) or isinstance(iplist, tuple) or isinstance(iplist, str)) :
+                raise KdlTypeError("iplist type error, should be a instance of list or tuple or str")
         if isinstance(iplist, list) or isinstance(iplist, tuple):
             iplist = ','.join(iplist)
         endpoint = EndPoint.SetIpWhitelist.value
@@ -73,10 +71,10 @@ class Client:
         return True
 
     def tps_current_ip(self, sign_type="simple"):
-        """仅支持支持换IP周期>=1分钟的隧道代理订单
+        """仅支持支持换ip周期>=1分钟的隧道代理订单
            获取隧道当前的IP，默认“simple”鉴权
            :param sign_type:默认simple
-           :return:返回ip地址。
+           :return:返回当前ip地址。
         """
         endpoint = EndPoint.TpsCurrentIp.value
         params = self._get_params(endpoint,sign_type=sign_type)
@@ -84,7 +82,7 @@ class Client:
         return res['data']['current_ip']
 
     def change_tps_ip(self, sign_type="simple"):
-        """仅支持支持换IP周期>=1分钟的隧道代理订单
+        """仅支持支持换ip周期>=1分钟的隧道代理订单
            :param sign_type: 默认simple
            :return: 返回新的IP地址
         """
@@ -93,8 +91,8 @@ class Client:
         res = self._get_base_res("GET",endpoint,params)
         return res['data']['new_ip']
     
-    def get_tps_ip(self, num=None, sign_type="simple", **kwargs):
-        """获取隧道代理IP, 默认"simple"鉴权 https://www.kuaidaili.com/doc/api/gettps/
+    def get_tps(self, num=None, sign_type="simple", **kwargs):
+        """获取隧道代理ip, 默认"simple"鉴权 https://www.kuaidaili.com/doc/api/gettps/
            :param num : 提取数量，int类型
            :param kwargs: 其他关键字参数，具体有那些参数请查看帮助中心api说明
            :return 若为json格式, 则返回data中proxy_list部分, 即proxy列表, 否则原样返回
@@ -272,7 +270,7 @@ class Client:
                 r = requests.post("https://" + endpoint, data=params)
 
             if r.status_code != 200:
-                raise KdlStatusErrorR(r.status_code, r.content.decode('utf8'))
+                raise KdlStatusError(r.status_code, r.content.decode('utf8'))
             try:
                 res = json.loads(r.content.decode('utf8'))
                 code, msg = res['code'], res['msg']
